@@ -1,17 +1,18 @@
-/*!
- * Should
- * Copyright(c) 2010-2014 TJ Holowaychuk <tj@vision-media.ca>
+/*
+ * should.js - assertion library
+ * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
+ * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-var util = require('../util')
-  , assert = require('assert')
-  , AssertionError = assert.AssertionError;
+var util = require('../util');
+var assert = require('./_assert');
+var AssertionError = require('../assertion-error');
 
 module.exports = function(should) {
   var i = should.format;
 
-  /**
+  /*
    * Expose assert to should
    *
    * This allows you to do things like below
@@ -25,32 +26,46 @@ module.exports = function(should) {
   /**
    * Assert _obj_ exists, with optional message.
    *
+   * @static
+   * @memberOf should
+   * @category assertion assert
+   * @alias should.exists
    * @param {*} obj
    * @param {String} [msg]
-   * @api public
+   * @example
+   *
+   * should.exist(1);
+   * should.exist(new Date());
    */
   should.exist = should.exists = function(obj, msg) {
-    if(null == obj) {
+    if (null == obj) {
       throw new AssertionError({
         message: msg || ('expected ' + i(obj) + ' to exist'), stackStartFunction: should.exist
       });
     }
   };
 
+  should.not = {};
   /**
    * Asserts _obj_ does not exist, with optional message.
    *
+   * @name not.exist
+   * @static
+   * @memberOf should
+   * @category assertion assert
+   * @alias should.not.exists
    * @param {*} obj
    * @param {String} [msg]
-   * @api public
+   * @example
+   *
+   * should.not.exist(null);
+   * should.not.exist(void 0);
    */
-
-  should.not = {};
   should.not.exist = should.not.exists = function(obj, msg) {
-    if(null != obj) {
+    if (null != obj) {
       throw new AssertionError({
         message: msg || ('expected ' + i(obj) + ' to not exist'), stackStartFunction: should.not.exist
       });
     }
   };
-};
\ No newline at end of file
+};
