@@ -3,28 +3,16 @@
  * Module dependencies.
  */
 
-var should = require('../')
-  , assert = require('assert');
+var should = require('../');
+var assert = require('assert');
 
-function err(fn, msg) {
-  try {
-    fn();
-    should.fail('expected an error');
-  } catch (err) {
-    should.equal(msg, err.message);
-  }
-}
 
 describe('should', function() {
-  it('test double require', function() {
-    require('../').should.equal(should);
-  });
-
   it('test assertion', function() {
-    'test'.should.be.a.string;
+    'test'.should.be.a.String;
     should.equal('foo', 'foo');
   });
-  
+
   it('test .expected and .actual', function() {
     try {
       'foo'.should.equal('bar');
@@ -33,7 +21,7 @@ describe('should', function() {
       assert('bar' == err.expected, 'err.expected');
     }
   });
- 
+
   it('test chaining', function() {
     var user = { name: 'tj', pets: ['tobi', 'loki', 'jane', 'bandit'] };
 
